url

# XMLRésuméLibrary: User Guide

uri | Element Reference | ward

## Name

url — A Uniform Resource Locator

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

### Important

The use of the `url` element as a child of `publisher` is deprecated as of XML Résumé Library version 1.4.0.

We recommend that you convert all `url`s contained in `publisher`s to `link`s.

The `url` element contains a single Uniform Resource Locator, as specified by RFC 1738 and RFC 1808.

### Formatting

There are two contexts in which a URL is formatted. The first is as an inline (e.g. when contained in a `para`). The second is as contact element (contained in a `contact`).

HTML

  When an inline, displayed as a hyperlink in a fixed-width font (enclosed in `code` tags). The “hot” text is the value of the element.

  When a contact element, displayed the same as when an inline, except not enclosed in `code` tags.

FO/PDF

  When an inline, displayed as non-hyperlinked text, using the font specified by the `url.font.family` parameter. (Default: `monospace`

  When a contact element, displayed as non-hyperlinked text, using the normal font.

Plain text

  Formatted as the value of the element.

### Parents

`url` may be contained in these elements: `achievement`, `contact`, `employer`, `institution`, `organization`, `para`, `project`, `pub`, `publisher`, `skill`

## See Also

`link`. `uri`.

## Examples

    <para>
      The Apache XML Project web page is located at
      <url>http://xml.apache.org/</url>.
    </para>

    <skill>
      Python (see <url>http://www.python.org/</url>)
    </skill>

uri | Element Reference | ward